@@ -10,22 +10,22 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'BINDIR': '/usr/bin',
  'BINLIBDEST': '/usr/lib/python2.7',
  'BLDLIBRARY': '-L. -lpython2.7',
- 'BLDSHARED': 'gcc -shared -Wl,-O1 -Wl,--sort-common -Wl,--as-needed -Wl,-z,relro -Wl,-z,now          -Wl,-z,pack-relative-relocs -flto=auto -L/usr/lib/openssl-1.1',
+ 'BLDSHARED': 'gcc -shared -Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now -L/usr/lib/openssl-1.1',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
  'CC': 'gcc',
  'CCSHARED': '-fPIC',
- 'CFLAGS': '-fno-strict-aliasing -march=x86-64 -mtune=generic -O3 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat -Werror=format-security         -fstack-clash-protection -fcf-protection -fno-semantic-interposition -flto=auto -std=c17 -DNDEBUG -march=x86-64 -mtune=generic -O3 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat -Werror=format-security         -fstack-clash-protection -fcf-protection -fno-semantic-interposition -flto=auto -std=c17',
+ 'CFLAGS': '-fno-strict-aliasing -march=x86-64 -mtune=generic -O2 -pipe -fstack-protector-strong -fno-plt -std=c17 -DNDEBUG -march=x86-64 -mtune=generic -O2 -pipe -fstack-protector-strong -fno-plt -std=c17',
  'CFLAGSFORSHARED': '-fPIC',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in Makefile.pre.in',
- 'CONFIG_ARGS': "'--prefix=/usr' '--enable-shared' '--with-threads' '--enable-optimizations' '--with-lto' '--enable-ipv6' '--enable-unicode=ucs4' '--with-system-expat' '--with-system-ffi' '--with-dbmliborder=gdbm:ndbm' '--without-ensurepip' 'CFLAGS=-march=x86-64 -mtune=generic -O3 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat -Werror=format-security         -fstack-clash-protection -fcf-protection -fno-semantic-interposition -flto=auto -std=c17' 'LDFLAGS=-Wl,-O1 -Wl,--sort-common -Wl,--as-needed -Wl,-z,relro -Wl,-z,now          -Wl,-z,pack-relative-relocs -flto=auto -L/usr/lib/openssl-1.1' 'CPPFLAGS= -I/usr/include/openssl-1.1'",
+ 'CONFIG_ARGS': "'--prefix=/usr' '--enable-shared' '--with-threads' '--enable-optimizations' '--with-lto' '--enable-ipv6' '--enable-unicode=ucs4' '--with-system-expat' '--with-system-ffi' '--with-dbmliborder=gdbm:ndbm' '--without-ensurepip' 'CFLAGS=-march=x86-64 -mtune=generic -O2 -pipe -fstack-protector-strong -fno-plt -std=c17' 'LDFLAGS=-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now -L/usr/lib/openssl-1.1' 'CPPFLAGS=-D_FORTIFY_SOURCE=2 -I/usr/include/openssl-1.1'",
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python2.7',
  'COREPYTHONPATH': ':plat-linux2:lib-tk:lib-old',
- 'COVERAGE_INFO': '/tmp/pkg/src/Python-2.7.18/coverage.info',
- 'COVERAGE_REPORT': '/tmp/pkg/src/Python-2.7.18/lcov-report',
+ 'COVERAGE_INFO': '/build/python2/src/Python-2.7.18/coverage.info',
+ 'COVERAGE_REPORT': '/build/python2/src/Python-2.7.18/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov report"',
- 'CPPFLAGS': '-I. -IInclude -I./Include  -I/usr/include/openssl-1.1',
+ 'CPPFLAGS': '-I. -IInclude -I./Include -D_FORTIFY_SOURCE=2 -I/usr/include/openssl-1.1',
  'CXX': 'g++',
  'C_THREADS': 0,
  'DESTDIRS': '/usr /usr/lib /usr/lib/python2.7 /usr/lib/python2.7/lib-dynload',
@@ -369,11 +369,11 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'INSTALL_SHARED': '/usr/bin/install -c -m 555',
  'INSTSONAME': 'libpython2.7.so.1.0',
  'LDCXXSHARED': 'g++ -shared',
- 'LDFLAGS': '-Wl,-O1 -Wl,--sort-common -Wl,--as-needed -Wl,-z,relro -Wl,-z,now          -Wl,-z,pack-relative-relocs -flto=auto -L/usr/lib/openssl-1.1',
+ 'LDFLAGS': '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now -L/usr/lib/openssl-1.1',
  'LDLAST': '',
  'LDLIBRARY': 'libpython2.7.so',
  'LDLIBRARYDIR': '',
- 'LDSHARED': 'gcc -shared -Wl,-O1 -Wl,--sort-common -Wl,--as-needed -Wl,-z,relro -Wl,-z,now          -Wl,-z,pack-relative-relocs -flto=auto -L/usr/lib/openssl-1.1',
+ 'LDSHARED': 'gcc -shared -Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now -L/usr/lib/openssl-1.1',
  'LIBC': '',
  'LIBDEST': '/usr/lib/python2.7',
  'LIBDIR': '/usr/lib',
@@ -408,7 +408,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'MAKESETUP': './Modules/makesetup',
  'MANDIR': '/usr/share/man',
  'MEMTESTOPTS': '-l -x test_subprocess test_io test_lib2to3 \\ -x test_dl test___all__ test_fork1 \\',
- 'MKDIR_P': '/usr/sbin/mkdir -p',
+ 'MKDIR_P': '/usr/bin/mkdir -p',
  'MODLIBS': '',
  'MODOBJS': 'Modules/threadmodule.o  Modules/signalmodule.o  Modules/posixmodule.o  Modules/errnomodule.o  Modules/pwdmodule.o  Modules/_sre.o  Modules/_codecsmodule.o  Modules/_weakref.o  Modules/zipimport.o  Modules/symtablemodule.o  Modules/xxsubtype.o',
  'MODULE_OBJS': '\\',
@@ -416,7 +416,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'MVWDELCH_IS_EXPRESSION': 1,
  'OBJECT_OBJS': '\\',
  'OLDPATH': ':lib-old',
- 'OPT': '-DNDEBUG -march=x86-64 -mtune=generic -O3 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat -Werror=format-security         -fstack-clash-protection -fcf-protection -fno-semantic-interposition -flto=auto -std=c17',
+ 'OPT': '-DNDEBUG -march=x86-64 -mtune=generic -O2 -pipe -fstack-protector-strong -fno-plt -std=c17',
  'OTHER_LIBTOOL_OPT': '',
  'PACKAGE_BUGREPORT': 0,
  'PACKAGE_NAME': 0,
@@ -453,7 +453,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'PYTHON_FOR_REGEN': 'python3',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
- 'PY_CFLAGS': '-fno-strict-aliasing -march=x86-64 -mtune=generic -O3 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat -Werror=format-security         -fstack-clash-protection -fcf-protection -fno-semantic-interposition -flto=auto -std=c17 -DNDEBUG -march=x86-64 -mtune=generic -O3 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat -Werror=format-security         -fstack-clash-protection -fcf-protection -fno-semantic-interposition -flto=auto -std=c17 -I. -IInclude -I./Include  -I/usr/include/openssl-1.1 -fPIC -DPy_BUILD_CORE',
+ 'PY_CFLAGS': '-fno-strict-aliasing -march=x86-64 -mtune=generic -O2 -pipe -fstack-protector-strong -fno-plt -std=c17 -DNDEBUG -march=x86-64 -mtune=generic -O2 -pipe -fstack-protector-strong -fno-plt -std=c17 -I. -IInclude -I./Include -D_FORTIFY_SOURCE=2 -I/usr/include/openssl-1.1 -fPIC -DPy_BUILD_CORE',
  'PY_FORMAT_LONG_LONG': '"ll"',
  'PY_FORMAT_SIZE_T': '"z"',
  'PY_UNICODE_TYPE': 'wchar_t',
@@ -465,7 +465,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'RANLIB': 'ranlib',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/tmp/pkg/src/Python-2.7.18',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python2/src/Python-2.7.18',
  'SCRIPTDIR': '/usr/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SGI_ABI': '',
@@ -508,7 +508,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'TESTOPTS': '-l',
  'TESTPATH': '',
  'TESTPROG': './Lib/test/regrtest.py',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/tmp/pkg/src/Python-2.7.18 ./python -Wd -3 -E -tt',
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python2/src/Python-2.7.18 ./python -Wd -3 -E -tt',
  'TESTPYTHONOPTS': '',
  'THREADOBJ': 'Python/thread.o',
  'TIME_WITH_SYS_TIME': 1,
@@ -533,8 +533,8 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/tmp/pkg/src/Python-2.7.18',
- 'abs_srcdir': '/tmp/pkg/src/Python-2.7.18',
+ 'abs_builddir': '/build/python2/src/Python-2.7.18',
+ 'abs_srcdir': '/build/python2/src/Python-2.7.18',
  'build': 'x86_64-pc-linux-gnu',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
